public enum CSSFlexDirection extends java.lang.Enum<CSSFlexDirection>
| Enum Constant and Description |
|---|
COLUMN |
COLUMN_REVERSE |
ROW |
ROW_REVERSE |
| Modifier and Type | Method and Description |
|---|---|
static CSSFlexDirection |
valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name.
|
static CSSFlexDirection[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CSSFlexDirection COLUMN
public static final CSSFlexDirection COLUMN_REVERSE
public static final CSSFlexDirection ROW
public static final CSSFlexDirection ROW_REVERSE
public static CSSFlexDirection[] values()
for (CSSFlexDirection c : CSSFlexDirection.values()) System.out.println(c);
public static CSSFlexDirection valueOf(java.lang.String name)
name - the name of the enum constant to be returned.java.lang.IllegalArgumentException - if this enum type has no constant with the specified namejava.lang.NullPointerException - if the argument is null