public enum CSSJustify extends java.lang.Enum<CSSJustify>
| Enum Constant and Description |
|---|
CENTER |
FLEX_END |
FLEX_START |
SPACE_AROUND |
SPACE_BETWEEN |
| Modifier and Type | Method and Description |
|---|---|
static CSSJustify |
valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name.
|
static CSSJustify[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CSSJustify FLEX_START
public static final CSSJustify CENTER
public static final CSSJustify FLEX_END
public static final CSSJustify SPACE_BETWEEN
public static final CSSJustify SPACE_AROUND
public static CSSJustify[] values()
for (CSSJustify c : CSSJustify.values()) System.out.println(c);
public static CSSJustify valueOf(java.lang.String name)
name - the name of the enum constant to be returned.java.lang.IllegalArgumentException - if this enum type has no constant with the specified namejava.lang.NullPointerException - if the argument is null