public enum CSSPositionType extends java.lang.Enum<CSSPositionType>
| Modifier and Type | Method and Description |
|---|---|
static CSSPositionType |
valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name.
|
static CSSPositionType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CSSPositionType RELATIVE
public static final CSSPositionType ABSOLUTE
public static CSSPositionType[] values()
for (CSSPositionType c : CSSPositionType.values()) System.out.println(c);
public static CSSPositionType valueOf(java.lang.String name)
name - the name of the enum constant to be returned.java.lang.IllegalArgumentException - if this enum type has no constant with the specified namejava.lang.NullPointerException - if the argument is null