public abstract class GuardedAsyncTask<Params,Progress>
extends android.os.AsyncTask<Params,Progress,java.lang.Void>
NativeModuleCallExceptionHandler registered if
the app is in dev mode.
This class doesn't allow doInBackground to return a results. This is mostly because when this
class was written that functionality wasn't used and it would require some extra code to make
work correctly with caught exceptions. Don't let that stop you from adding it if you need it :)| Modifier | Constructor and Description |
|---|---|
protected |
GuardedAsyncTask(ReactContext reactContext) |
| Modifier and Type | Method and Description |
|---|---|
protected java.lang.Void |
doInBackground(Params... params) |
protected abstract void |
doInBackgroundGuarded(Params... params) |
protected GuardedAsyncTask(ReactContext reactContext)