Interface that represents a JavaScript Promise which can be passed to the native module as a
method parameter.
Methods annotated with ReactMethod that use Promise as type of the last parameter
will be marked as "remoteAsync" and will return a promise when invoked from JavaScript.