public class ProxyJavaScriptExecutor extends JavaScriptExecutor
CatalystInstance.Builder, catalyst native code will delegate
low level javascript calls to the implementation of JavaJSExecutor interface provided
with the constructor of this class.| Constructor and Description |
|---|
ProxyJavaScriptExecutor(JavaJSExecutor executor)
Create
ProxyJavaScriptExecutor instance |
| Modifier and Type | Method and Description |
|---|---|
void |
close()
Close this executor and cleanup any resources that it was using.
|
public ProxyJavaScriptExecutor(JavaJSExecutor executor)
ProxyJavaScriptExecutor instanceexecutor - implementation of JavaJSExecutor which will be responsible for handling
javascript callspublic void close()
JavaScriptExecutorclose in class JavaScriptExecutor