public class ReactBridge extends Countable
| Constructor and Description |
|---|
ReactBridge(JavaScriptExecutor jsExecutor,
ReactCallback callback,
MessageQueueThread nativeModulesQueueThread) |
| Modifier and Type | Method and Description |
|---|---|
void |
callFunction(int moduleId,
int methodId,
NativeArray arguments) |
void |
dispose() |
void |
invokeCallback(int callbackID,
NativeArray arguments) |
void |
loadScriptFromAssets(android.content.res.AssetManager assetManager,
java.lang.String assetName)
All native functions are not thread safe and appropriate queues should be used
|
void |
loadScriptFromFile(java.lang.String fileName,
java.lang.String sourceURL) |
void |
setGlobalVariable(java.lang.String propertyName,
java.lang.String jsonEncodedArgument) |
void |
startProfiler(java.lang.String title) |
void |
stopProfiler(java.lang.String title,
java.lang.String filename) |
boolean |
supportsProfiling() |
public ReactBridge(JavaScriptExecutor jsExecutor, ReactCallback callback, MessageQueueThread nativeModulesQueueThread)
jsExecutor - the JS executor to use to run JScallback - the callback class used to invoke native modulesnativeModulesQueueThread - the MessageQueueThread the callbacks should be invoked onpublic void loadScriptFromAssets(android.content.res.AssetManager assetManager,
java.lang.String assetName)
public void loadScriptFromFile(@Nullable
java.lang.String fileName,
@Nullable
java.lang.String sourceURL)
public void callFunction(int moduleId,
int methodId,
NativeArray arguments)
public void invokeCallback(int callbackID,
NativeArray arguments)
public void setGlobalVariable(java.lang.String propertyName,
java.lang.String jsonEncodedArgument)
public boolean supportsProfiling()
public void startProfiler(java.lang.String title)
public void stopProfiler(java.lang.String title,
java.lang.String filename)