public class SoftAssertions
extends java.lang.Object
NativeModuleCallExceptionHandler. See the javadoc on that class for
more information about our opinion on when these assertions should be used as opposed to
assertions that might throw AssertionError Throwables that will cause the app to hard crash.| Constructor and Description |
|---|
SoftAssertions() |
| Modifier and Type | Method and Description |
|---|---|
static void |
assertCondition(boolean condition,
java.lang.String message)
Asserts the given condition, throwing an
AssertionException if the condition doesn't
hold. |
static <T> T |
assertNotNull(T instance)
Asserts that the given Object isn't null, throwing an
AssertionException if it was. |
public static void assertCondition(boolean condition,
java.lang.String message)
AssertionException if the condition doesn't
hold.public static <T> T assertNotNull(@Nullable
T instance)
AssertionException if it was.