| Interface | Description |
|---|---|
| Callback |
Interface that represent javascript callback function which can be passed to the native module
as a method parameter.
|
| JavaScriptModule |
Interface denoting that a class is the interface to a module with the same name in JS.
|
| JSDebuggerWebSocketClient.JSDebuggerCallback | |
| LifecycleEventListener |
Listener for receiving activity/service lifecycle events.
|
| NativeModule |
A native module whose API can be provided to JS catalyst instances.
|
| NativeModule.NativeMethod | |
| NativeModuleCallExceptionHandler |
Interface for a class that knows how to handle an Exception thrown by a native module invoked
from JS.
|
| NotThreadSafeBridgeIdleDebugListener |
Interface for receiving notification for bridge idle/busy events.
|
| OnBatchCompleteListener |
Interface for a module that will be notified when a batch of JS->Java calls has finished.
|
| ProxyJavaScriptExecutor.JavaJSExecutor |
This is class represents java version of native js executor interface.
|
| ReactCallback | |
| ReadableArray |
Interface for an array that allows typed access to its members.
|
| ReadableMap |
Interface for a map that allows typed access to its members.
|
| ReadableMapKeySeyIterator |
Interface of a iterator for a
NativeMap's key set. |
| WebsocketJavaScriptExecutor.JSExecutorConnectCallback | |
| WritableArray |
Interface for a mutable array.
|
| WritableMap |
Interface for a mutable map.
|
| Class | Description |
|---|---|
| Arguments | |
| BaseJavaModule |
Base class for Catalyst native modules whose implementations are written in Java.
|
| CallbackImpl |
Implementation of javascript callback function that use Bridge to schedule method execution
|
| CatalystInstance |
A higher level API on top of the asynchronous JSC bridge.
|
| CatalystInstance.Builder | |
| GuardedAsyncTask<Params,Progress> |
Abstract base for a AsyncTask that should have any RuntimeExceptions it throws
handled by the
NativeModuleCallExceptionHandler registered if
the app is in dev mode. |
| JavaScriptExecutor | |
| JavaScriptModulesConfig |
Class stores configuration of javascript modules that can be used across the bridge
|
| JavaScriptModulesConfig.Builder | |
| JSBundleLoader |
A class that stores JS bundle information and allows
CatalystInstance to load a correct
bundle through ReactBridge. |
| JSCJavaScriptExecutor | |
| JSDebuggerWebSocketClient |
A wrapper around WebSocketClient that recognizes RN debugging message format.
|
| JsonGeneratorHelper |
Helper for generating JSON for lists and maps.
|
| NativeArray |
Base class for an array whose members are stored in native code (C++).
|
| NativeMap |
Base class for a Map whose keys and values are stored in native code (C++).
|
| NativeModuleRegistry |
A set of Java APIs to expose to a particular JavaScript instance.
|
| NativeModuleRegistry.Builder | |
| ProxyJavaScriptExecutor |
JavaScript executor that delegates JS calls processed by native code back to a java version
of the native executor interface.
|
| ReactApplicationContext |
A context wrapper that always wraps Android Application
Context and
CatalystInstance by extending ReactContext |
| ReactBridge |
Interface to the JS execution environment and means of transport for messages Java<->JS.
|
| ReactContext |
Abstract ContextWrapper for Android applicaiton or activity
Context and
CatalystInstance |
| ReactContextBaseJavaModule |
Base class for Catalyst native modules that require access to the
ReactContext
instance. |
| ReadableNativeArray |
Implementation of a NativeArray that allows read-only access to its members.
|
| ReadableNativeMap |
Implementation of a read-only map in native memory.
|
| SoftAssertions |
Utility class to make assertions that should not hard-crash the app but instead be handled by the
Catalyst app
NativeModuleCallExceptionHandler. |
| UiThreadUtil |
Utility for interacting with the UI thread.
|
| WebsocketJavaScriptExecutor |
Executes JS remotely via the react nodejs server as a proxy to a browser on the host machine.
|
| WritableNativeArray |
Implementation of a write-only array stored in native memory.
|
| WritableNativeMap |
Implementation of a write-only map stored in native memory.
|
| Enum | Description |
|---|---|
| ReadableType |
Defines the type of an object stored in a
ReadableArray or
ReadableMap. |
| Exception | Description |
|---|---|
| AssertionException |
Like
AssertionError but extends RuntimeException so that it may be caught by a
NativeModuleCallExceptionHandler. |
| InvalidIteratorException |
Exception thrown by
ReadableMapKeySeyIterator.nextKey() when the iterator tries
to iterate over elements after the end of the key set. |
| JSApplicationCausedNativeException |
A special RuntimeException that should be thrown by native code if it has reached an exceptional
state due to a, or a sequence of, bad commands.
|
| JSApplicationIllegalArgumentException |
An illegal argument Exception caused by an argument passed from JS.
|
| NativeArgumentsParseException |
Exception thrown when a native module method call receives unexpected arguments from JS.
|
| NoSuchKeyException |
Exception thrown by
ReadableNativeMap when a key that does not exist is requested. |
| ObjectAlreadyConsumedException |
Exception thrown when a caller attempts to modify or use a
WritableNativeArray or
WritableNativeMap after it has already been added to a parent array or map. |
| ProxyJavaScriptExecutor.ProxyExecutorException | |
| UnexpectedNativeTypeException |
Exception thrown from native code when a type retrieved from a map or array (e.g.
|
| WebsocketJavaScriptExecutor.WebsocketExecutorTimeoutException |
| Annotation Type | Description |
|---|---|
| ReactMethod |
Annotation which is used to mark methods that are exposed to
Catalyst.
|