public class CatalystQueueConfigurationImpl extends java.lang.Object implements CatalystQueueConfiguration
| Modifier and Type | Method and Description |
|---|---|
static CatalystQueueConfigurationImpl |
create(CatalystQueueConfigurationSpec spec,
QueueThreadExceptionHandler exceptionHandler) |
void |
destroy()
Should be called when the corresponding
CatalystInstance
is destroyed so that we shut down the proper queue threads. |
MessageQueueThread |
getJSQueueThread() |
MessageQueueThread |
getNativeModulesQueueThread() |
MessageQueueThread |
getUIQueueThread() |
public MessageQueueThread getUIQueueThread()
getUIQueueThread in interface CatalystQueueConfigurationpublic MessageQueueThread getNativeModulesQueueThread()
getNativeModulesQueueThread in interface CatalystQueueConfigurationpublic MessageQueueThread getJSQueueThread()
getJSQueueThread in interface CatalystQueueConfigurationpublic void destroy()
CatalystInstance
is destroyed so that we shut down the proper queue threads.public static CatalystQueueConfigurationImpl create(CatalystQueueConfigurationSpec spec, QueueThreadExceptionHandler exceptionHandler)