| Interface | Description |
|---|---|
| CatalystQueueConfiguration |
Specifies which
MessageQueueThreads must be used to run the various contexts of
execution within catalyst (Main UI thread, native modules, and JS). |
| MessageQueueThread |
Encapsulates a Thread that can accept Runnables.
|
| QueueThreadExceptionHandler |
Interface for a class that knows how to handle an Exception thrown while executing a Runnable
submitted via
MessageQueueThread.runOnQueue(java.lang.Runnable). |
| Class | Description |
|---|---|
| CatalystQueueConfigurationImpl | |
| CatalystQueueConfigurationSpec |
Spec for creating a CatalystQueueConfiguration.
|
| CatalystQueueConfigurationSpec.Builder | |
| MessageQueueThreadHandler |
Handler that can catch and dispatch Exceptions to an Exception handler.
|
| MessageQueueThreadImpl |
Encapsulates a Thread that has a
Looper running on it that can accept Runnables. |
| MessageQueueThreadRegistry |
A utility for getting the MessageQueueThread for the current thread.
|
| MessageQueueThreadSpec |
Spec for creating a MessageQueueThread.
|
| NativeRunnable |
A Runnable that has a native run implementation.
|
| NativeRunnableDeprecated |
A Runnable that has a native run implementation.
|
| ProxyQueueThreadExceptionHandler |
An Exception handler that posts the Exception to be thrown on the given delegate
MessageQueueThread.
|
| Enum | Description |
|---|---|
| MessageQueueThreadSpec.ThreadType |