| Interface | Description |
|---|---|
| DevOptionHandler |
Callback class for custom options that may appear in
DevSupportManager developer
options menu. |
| ReactInstanceDevCommandsHandler |
Interface used by
DevSupportManager for requesting React instance recreation
based on the option that user select in developers menu. |
| Class | Description |
|---|---|
| DevInternalSettings |
Helper class for accessing developers settings that should not be accessed outside of the package
com.facebook.react.devsupport. |
| DevSettingsActivity |
Activity that display developers settings.
|
| DevSupportManager |
Interface for accessing and interacting with development features.
|
| FpsView |
View that automatically monitors and displays the current app frame rate.
|
| Exception | Description |
|---|---|
| DebugServerException |
The debug server returns errors as json objects.
|