public class DeviceEventManagerModule extends ReactContextBaseJavaModule
| Modifier and Type | Class and Description |
|---|---|
static interface |
DeviceEventManagerModule.RCTDeviceEventEmitter |
NativeModule.NativeMethod| Constructor and Description |
|---|
DeviceEventManagerModule(ReactApplicationContext reactContext,
DefaultHardwareBackBtnHandler backBtnHandler) |
| Modifier and Type | Method and Description |
|---|---|
void |
emitHardwareBackPressed()
Sends an event to the JS instance that the hardware back has been pressed.
|
java.lang.String |
getName() |
void |
invokeDefaultBackPressHandler()
Invokes the default back handler for the host of this catalyst instance.
|
getReactApplicationContextgetConstants, getMethods, initialize, onCatalystInstanceDestroy, writeConstantsFieldpublic DeviceEventManagerModule(ReactApplicationContext reactContext, DefaultHardwareBackBtnHandler backBtnHandler)
public void emitHardwareBackPressed()
public void invokeDefaultBackPressHandler()
public java.lang.String getName()
require() this module
from javascript.