| Class | Description |
|---|---|
| ForwardingCookieHandler |
Cookie handler that forwards all cookies to the WebView CookieManager.
|
| NetworkingModule |
Implements the XMLHttpRequest JavaScript interface.
|
| OkHttpClientProvider |
Helper class that provides the same OkHttpClient instance that will be used for all networking
requests.
|