| Interface | Description |
|---|---|
| ReactInstanceManager.ReactInstanceEventListener |
Listener interface for react instance events.
|
| ReactPackage |
Main interface for providing additional capabilities to the catalyst framework by couple of
different means:
1) Registering new native modules
2) Registering new JS modules that may be accessed from native modules or from other parts of the
native code (requiring JS modules from the package doesn't mean it will automatically be included
as a part of the JS bundle, so there should be a corresponding piece of code on JS side that will
require implementation of that JS module so that it gets bundled)
3) Registering custom native views (view managers) and custom event types
4) Registering natively packaged assets/resources (e.g.
|
| Class | Description |
|---|---|
| CompositeReactPackage |
CompositeReactPackage allows to create a single package composed of views and modules
from several other packages. |
| MemoryPressureRouter |
Translates and routes memory pressure events to the current catalyst instance.
|
| ReactActivity |
Base Activity for React Native applications.
|
| ReactInstanceManager |
This class is managing instances of
CatalystInstance. |
| ReactInstanceManager.Builder |
Builder class for
ReactInstanceManagerImpl |
| ReactRootView |
Default root view for catalyst apps.
|
| Enum | Description |
|---|---|
| LifecycleState |
Lifecycle state for an Activity.
|