| Interface | Description |
|---|---|
| DebugComponentOwnershipModule.OwnerHierarchyCallback |
Callback for when we receive the ownership hierarchy in native code.
|
| DebugComponentOwnershipModule.RCTDebugComponentOwnership | |
| NotThreadSafeUiManagerDebugListener |
A listener that is notified about
UIManagerModule events. |
| Class | Description |
|---|---|
| DebugComponentOwnershipModule |
Native module that can asynchronously request the owners hierarchy of a react tag.
|