| Interface | Description |
|---|---|
| AppRegistry |
JS module interface - main entry point for launching React application for a given key.
|
| ReactCompoundView |
This interface should be implemented be native
View subclasses that can represent more
than a single react node (e.g. |
| ReactNative |
JS module interface - used by UIManager to communicate with main React JS module methods
|
| ReactPointerEventsView |
This interface should be implemented be native
View subclasses that support pointer
events handling. |
| RootView |
Interface for the root native view of a React native application.
|
| SizeMonitoringFrameLayout.OnSizeChangedListener |
| Class | Description |
|---|---|
| BaseViewManager<T extends android.view.View,C extends LayoutShadowNode> |
Base class that should be suitable for the majority of subclasses of
ViewManager. |
| CatalystStylesDiffMap |
Wrapper for
ReadableMap which should be used for styles property map. |
| DisplayMetricsHolder |
Holds an instance of the current DisplayMetrics so we don't have to thread it through all the
classes that need it.
|
| GuardedChoreographerFrameCallback |
Abstract base for a Choreographer FrameCallback that should have any RuntimeExceptions it throws
handled by the
NativeModuleCallExceptionHandler registered if
the app is in dev mode. |
| LayoutShadowNode |
Supply setters for base view layout properties such as width, height, flex properties,
borders, etc.
|
| MeasureSpecAssertions |
Shared utility for asserting on MeasureSpecs.
|
| NativeViewHierarchyOptimizer |
Class responsible for optimizing the native view hierarchy while still respecting the final UI
product specified by JS.
|
| PixelUtil |
Android dp to pixel manipulation
|
| ReactChoreographer |
A simple wrapper around Choreographer that allows us to control the order certain callbacks
are executed within a given frame.
|
| ReactShadowNode |
Base node class for representing virtual tree of React nodes.
|
| RootViewManager |
View manager for ReactRootView components.
|
| RootViewUtil | |
| SimpleViewManager<T extends android.view.View> |
Common base class for most of the
ViewManagers. |
| SizeMonitoringFrameLayout |
Subclass of
FrameLayout that allows registering for size change events. |
| ThemedReactContext |
Wraps
ReactContext with the base Context passed into the constructor. |
| TouchTargetHelper |
Class responsible for identifying which react view should handle a given
MotionEvent. |
| UIManagerModule |
Native module to allow JS to create and update native Views.
|
| UIViewOperationQueue |
This class acts as a buffer for command executed on
NativeViewHierarchyManager or on
AnimationRegistry. |
| ViewDefaults |
Default property values for Views to be shared between Views and ShadowViews.
|
| ViewGroupManager<T extends android.view.ViewGroup> |
Class providing children management API for view managers of classes extending ViewGroup.
|
| ViewManager<T extends android.view.View,C extends ReactShadowNode> |
Class responsible for knowing how to create and update catalyst Views of a given type.
|
| ViewProps |
Keys for props that need to be shared across multiple classes.
|
| Enum | Description |
|---|---|
| PointerEvents |
Possible values for pointer events that a view and its descendants should receive.
|
| ReactChoreographer.CallbackType |
| Exception | Description |
|---|---|
| IllegalViewOperationException |
An exception caused by JS requesting the UI manager to perform an illegal view operation.
|
| NoSuchNativeViewException |
Exception thrown when a class tries to access a native view by a tag that has no native view
associated with it.
|
| ReactInvalidPropertyException |
| Annotation Type | Description |
|---|---|
| ReactProp |
Use this annotation to annotate properties of native views that should be exposed to JS.
|
| ReactPropGroup |
Use this annotation to annotate group of properties of native views that should be exposed to JS.
|