public class ARTSurfaceViewShadowNode extends LayoutShadowNode
CSSNode.MeasureFunction| Constructor and Description |
|---|
ARTSurfaceViewShadowNode() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
isVirtual()
Nodes that return
true will be treated as "virtual" nodes. |
boolean |
isVirtualAnchor()
Nodes that return
true will be treated as a root view for the virtual nodes tree. |
void |
onCollectExtraUpdates(UIViewOperationQueue uiUpdater)
Called after layout step at the end of the UI batch from
UIManagerModule. |
setAlignItems, setAlignSelf, setBorderWidths, setBottom, setFlex, setFlexDirection, setFlexWrap, setHeight, setJustifyContent, setLeft, setMargins, setPaddings, setPosition, setRight, setShouldNotifyOnLayout, setTop, setWidthaddChildAt, addNativeChildAt, dirty, getChildAt, getNativeChildCount, getNativeOffsetForChild, getNativeParent, getParent, getReactTag, getRootNode, getScreenHeight, getScreenWidth, getScreenX, getScreenY, getThemedContext, getTotalNativeChildren, getViewClass, hasUpdates, indexOfNativeChild, isLayoutOnly, markUpdated, markUpdateSeen, onAfterUpdateTransaction, onBeforeLayout, removeAllChildren, removeAllNativeChildren, removeChildAt, removeNativeChildAt, setIsLayoutOnly, setThemedContext, shouldNotifyOnLayout, updatePropertiescalculateLayout, getAlignItems, getAlignSelf, getBorder, getChildCount, getFlex, getFlexDirection, getJustifyContent, getLayoutDirection, getLayoutHeight, getLayoutWidth, getLayoutX, getLayoutY, getMargin, getPadding, getPositionBottom, getPositionLeft, getPositionRight, getPositionTop, getPositionType, getStyleDirection, getStyleHeight, getStyleWidth, hasNewLayout, indexOf, isDirty, isMeasureDefined, markLayoutSeen, reset, setAlignItems, setAlignSelf, setBorder, setDefaultPadding, setDirection, setFlexDirection, setJustifyContent, setMargin, setMeasureFunction, setPadding, setPositionBottom, setPositionLeft, setPositionRight, setPositionTop, setPositionType, setStyleHeight, setStyleWidth, setWrap, toString, valuesEqualpublic boolean isVirtual()
ReactShadowNodetrue will be treated as "virtual" nodes. That is, nodes that are not
mapped into native views (e.g. nested text node). By default this method returns false.isVirtual in class ReactShadowNodepublic boolean isVirtualAnchor()
ReactShadowNodetrue will be treated as a root view for the virtual nodes tree. It
means that NativeViewHierarchyManager will not try to perform manageChildren
operation on such views. Good example is InputText view that may have children
Text nodes but this whole hierarchy will be mapped to a single android EditText
view.isVirtualAnchor in class ReactShadowNodepublic void onCollectExtraUpdates(UIViewOperationQueue uiUpdater)
ReactShadowNodeUIManagerModule. May be used
to enqueue additional ui operations for the native view. Will only be called on nodes marked
as updated either with ReactShadowNode.dirty() or ReactShadowNode.markUpdated().onCollectExtraUpdates in class ReactShadowNodeuiUpdater - interface for enqueueing UI operations