public class ReactImageManager extends SimpleViewManager<ReactImageView>
| Modifier and Type | Field and Description |
|---|---|
static java.lang.String |
REACT_CLASS |
PROP_TEST_ID| Constructor and Description |
|---|
ReactImageManager() |
ReactImageManager(AbstractDraweeControllerBuilder draweeControllerBuilder,
java.lang.Object callerContext) |
| Modifier and Type | Method and Description |
|---|---|
ReactImageView |
createViewInstance(ThemedReactContext context)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
protected void |
onAfterUpdateTransaction(ReactImageView view)
Callback that will be triggered after all properties are updated in current update transaction
(all @ReactProp handlers for properties updated in current transaction have been called).
|
void |
setBorderColor(ReactImageView view,
java.lang.Integer borderColor) |
void |
setBorderRadius(ReactImageView view,
float borderRadius) |
void |
setBorderWidth(ReactImageView view,
float borderWidth) |
void |
setFadeDuration(ReactImageView view,
int durationMs) |
void |
setProgressiveRenderingEnabled(ReactImageView view,
boolean enabled) |
void |
setResizeMode(ReactImageView view,
java.lang.String resizeMode) |
void |
setSource(ReactImageView view,
java.lang.String source) |
void |
setTintColor(ReactImageView view,
java.lang.Integer tintColor) |
createShadowNodeInstance, getShadowNodeClass, updateExtraDatasetAccessibilityComponentType, setAccessibilityLabel, setAccessibilityLiveRegion, setBackgroundColor, setDecomposedMatrix, setImportantForAccessibility, setOpacity, setRenderToHardwareTexture, setRotation, setScaleX, setScaleY, setTestId, setTranslateX, setTranslateYaddEventEmitters, createView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onDropViewInstance, receiveCommand, updatePropertiespublic static final java.lang.String REACT_CLASS
public ReactImageManager(AbstractDraweeControllerBuilder draweeControllerBuilder,
java.lang.Object callerContext)
public ReactImageManager()
public java.lang.String getName()
getName in class ViewManager<ReactImageView,LayoutShadowNode>public ReactImageView createViewInstance(ThemedReactContext context)
ViewManagercreateViewInstance in class ViewManager<ReactImageView,LayoutShadowNode>public void setSource(ReactImageView view, @Nullable java.lang.String source)
public void setBorderColor(ReactImageView view, @Nullable java.lang.Integer borderColor)
public void setBorderWidth(ReactImageView view, float borderWidth)
public void setBorderRadius(ReactImageView view, float borderRadius)
public void setResizeMode(ReactImageView view, @Nullable java.lang.String resizeMode)
public void setTintColor(ReactImageView view, @Nullable java.lang.Integer tintColor)
public void setProgressiveRenderingEnabled(ReactImageView view, boolean enabled)
public void setFadeDuration(ReactImageView view, int durationMs)
protected void onAfterUpdateTransaction(ReactImageView view)
ViewManageronAfterUpdateTransaction in class ViewManager<ReactImageView,LayoutShadowNode>