public class ProgressBarShadowNode extends LayoutShadowNode implements CSSNode.MeasureFunction
android.R.attr.progressBarStyle for possible styles. ReactProgressBarViewManager
manages how this style is applied to the ProgressBar.CSSNode.MeasureFunction| Constructor and Description |
|---|
ProgressBarShadowNode() |
| Modifier and Type | Method and Description |
|---|---|
java.lang.String |
getStyle() |
void |
measure(CSSNode node,
float width,
float height,
MeasureOutput measureOutput)
Should measure the given node and put the result in the given MeasureOutput.
|
void |
setStyle(java.lang.String style) |
setAlignItems, setAlignSelf, setBorderWidths, setBottom, setFlex, setFlexDirection, setFlexWrap, setHeight, setJustifyContent, setLeft, setMargins, setPaddings, setPosition, setRight, setShouldNotifyOnLayout, setTop, setWidthaddChildAt, addNativeChildAt, dirty, getChildAt, getNativeChildCount, getNativeOffsetForChild, getNativeParent, getParent, getReactTag, getRootNode, getScreenHeight, getScreenWidth, getScreenX, getScreenY, getThemedContext, getTotalNativeChildren, getViewClass, hasUpdates, indexOfNativeChild, isLayoutOnly, isVirtual, isVirtualAnchor, markUpdated, markUpdateSeen, onAfterUpdateTransaction, onBeforeLayout, onCollectExtraUpdates, removeAllChildren, removeAllNativeChildren, removeChildAt, removeNativeChildAt, setIsLayoutOnly, setThemedContext, shouldNotifyOnLayout, updatePropertiescalculateLayout, getAlignItems, getAlignSelf, getBorder, getChildCount, getFlex, getFlexDirection, getJustifyContent, getLayoutDirection, getLayoutHeight, getLayoutWidth, getLayoutX, getLayoutY, getMargin, getPadding, getPositionBottom, getPositionLeft, getPositionRight, getPositionTop, getPositionType, getStyleDirection, getStyleHeight, getStyleWidth, hasNewLayout, indexOf, isDirty, isMeasureDefined, markLayoutSeen, reset, setAlignItems, setAlignSelf, setBorder, setDefaultPadding, setDirection, setFlexDirection, setJustifyContent, setMargin, setMeasureFunction, setPadding, setPositionBottom, setPositionLeft, setPositionRight, setPositionTop, setPositionType, setStyleHeight, setStyleWidth, setWrap, toString, valuesEqual@Nullable public java.lang.String getStyle()
public void setStyle(@Nullable
java.lang.String style)
public void measure(CSSNode node, float width, float height, MeasureOutput measureOutput)
CSSNode.MeasureFunctionmeasure in interface CSSNode.MeasureFunction