public class ReactProgressBarViewManager extends ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>
| Modifier and Type | Field and Description |
|---|---|
static java.lang.String |
PROP_STYLE |
| Constructor and Description |
|---|
ReactProgressBarViewManager() |
| Modifier and Type | Method and Description |
|---|---|
ProgressBarShadowNode |
createCSSNodeInstance()
This method should return a subclass of
CSSNode which will be then used for measuring
position and size of the view. |
protected android.widget.FrameLayout |
createViewInstance(ThemedReactContext context)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
void |
updateExtraData(android.widget.FrameLayout root,
java.lang.Object extraData)
Subclasses can implement this method to receive an optional extra data enqueued from the
corresponding instance of
ReactShadowNode in
ReactShadowNode.onCollectExtraUpdates(com.facebook.react.uimanager.UIViewOperationQueue). |
void |
updateView(android.widget.FrameLayout view,
CatalystStylesDiffMap props)
Subclass should use this method to populate native view with updated style properties.
|
addEventEmitters, createView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onAfterUpdateTransaction, onDropViewInstance, receiveCommand, updatePropertiespublic static final java.lang.String PROP_STYLE
public java.lang.String getName()
getName in class ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>protected android.widget.FrameLayout createViewInstance(ThemedReactContext context)
ViewManagercreateViewInstance in class ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>public void updateView(android.widget.FrameLayout view,
CatalystStylesDiffMap props)
ViewManagerupdateView in class ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>public ProgressBarShadowNode createCSSNodeInstance()
ViewManagerCSSNode which will be then used for measuring
position and size of the view. In mose of the cases this should just return an instance of
CSSNodecreateCSSNodeInstance in class ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>public void updateExtraData(android.widget.FrameLayout root,
java.lang.Object extraData)
ViewManagerReactShadowNode in
ReactShadowNode.onCollectExtraUpdates(com.facebook.react.uimanager.UIViewOperationQueue).
Since css layout step and ui updates can be executed in separate thread apart of setting
x/y/width/height this is the recommended and thread-safe way of passing extra data from css
node to the native view counterpart.
TODO(7247021): Replace updateExtraData with generic update props mechanism after D2086999updateExtraData in class ViewManager<android.widget.FrameLayout,ProgressBarShadowNode>