public class ReactHorizontalScrollViewManager extends ViewGroupManager<ReactHorizontalScrollView> implements ReactScrollViewCommandHelper.ScrollCommandHandler<ReactHorizontalScrollView>
ReactHorizontalScrollView components.
Note that ReactScrollView and ReactHorizontalScrollView are exposed to JS
as a single ScrollView component, configured via the horizontal boolean property.
PROP_TEST_ID| Constructor and Description |
|---|
ReactHorizontalScrollViewManager() |
| Modifier and Type | Method and Description |
|---|---|
ReactHorizontalScrollView |
createViewInstance(ThemedReactContext context)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
void |
receiveCommand(ReactHorizontalScrollView scrollView,
int commandId,
ReadableArray args)
Subclasses may use this method to receive events/commands directly from JS through the
UIManager. |
void |
scrollTo(ReactHorizontalScrollView scrollView,
ReactScrollViewCommandHelper.ScrollToCommandData data) |
void |
scrollWithoutAnimationTo(ReactHorizontalScrollView scrollView,
ReactScrollViewCommandHelper.ScrollToCommandData data) |
void |
setShowsHorizontalScrollIndicator(ReactHorizontalScrollView view,
boolean value) |
addView, createShadowNodeInstance, getChildAt, getChildCount, getShadowNodeClass, needsCustomLayoutForChildren, removeAllViews, removeViewAt, updateExtraDatasetAccessibilityComponentType, setAccessibilityLabel, setAccessibilityLiveRegion, setBackgroundColor, setDecomposedMatrix, setImportantForAccessibility, setOpacity, setRenderToHardwareTexture, setRotation, setScaleX, setScaleY, setTestId, setTranslateX, setTranslateYaddEventEmitters, createView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onAfterUpdateTransaction, onDropViewInstance, updatePropertiespublic java.lang.String getName()
getName in class ViewManager<ReactHorizontalScrollView,LayoutShadowNode>public ReactHorizontalScrollView createViewInstance(ThemedReactContext context)
ViewManagercreateViewInstance in class ViewManager<ReactHorizontalScrollView,LayoutShadowNode>public void setShowsHorizontalScrollIndicator(ReactHorizontalScrollView view, boolean value)
public void receiveCommand(ReactHorizontalScrollView scrollView, int commandId, @Nullable ReadableArray args)
ViewManagerUIManager. Good example of such a command would be scrollTo request with
coordinates for a ScrollView or goBack request for a WebView instance.receiveCommand in class ViewManager<ReactHorizontalScrollView,LayoutShadowNode>scrollView - View instance that should receive the commandcommandId - code of the commandargs - optional arguments for the commandpublic void scrollTo(ReactHorizontalScrollView scrollView, ReactScrollViewCommandHelper.ScrollToCommandData data)
scrollTo in interface ReactScrollViewCommandHelper.ScrollCommandHandler<ReactHorizontalScrollView>public void scrollWithoutAnimationTo(ReactHorizontalScrollView scrollView, ReactScrollViewCommandHelper.ScrollToCommandData data)
scrollWithoutAnimationTo in interface ReactScrollViewCommandHelper.ScrollCommandHandler<ReactHorizontalScrollView>