public class ReactSwitchManager extends SimpleViewManager<com.facebook.react.views.switchviewview.ReactSwitch>
ReactSwitch components.| Modifier and Type | Field and Description |
|---|---|
static java.lang.String |
PROP_ENABLED |
static java.lang.String |
PROP_ON |
| Constructor and Description |
|---|
ReactSwitchManager() |
| Modifier and Type | Method and Description |
|---|---|
protected void |
addEventEmitters(ThemedReactContext reactContext,
com.facebook.react.views.switchviewview.ReactSwitch view)
Subclasses can override this method to install custom event emitters on the given View.
|
ReactShadowNode |
createCSSNodeInstance()
This method should return a subclass of
CSSNode which will be then used for measuring
position and size of the view. |
protected com.facebook.react.views.switchviewview.ReactSwitch |
createViewInstance(ThemedReactContext context)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
void |
updateView(com.facebook.react.views.switchviewview.ReactSwitch view,
CatalystStylesDiffMap props)
Subclass should use this method to populate native view with updated style properties.
|
updateExtraDatacreateView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onAfterUpdateTransaction, onDropViewInstance, receiveCommand, updatePropertiespublic static final java.lang.String PROP_ENABLED
public static final java.lang.String PROP_ON
public java.lang.String getName()
getName in class ViewManager<com.facebook.react.views.switchviewview.ReactSwitch,ReactShadowNode>public ReactShadowNode createCSSNodeInstance()
ViewManagerCSSNode which will be then used for measuring
position and size of the view. In mose of the cases this should just return an instance of
CSSNodecreateCSSNodeInstance in class SimpleViewManager<com.facebook.react.views.switchviewview.ReactSwitch>protected com.facebook.react.views.switchviewview.ReactSwitch createViewInstance(ThemedReactContext context)
ViewManagercreateViewInstance in class ViewManager<com.facebook.react.views.switchviewview.ReactSwitch,ReactShadowNode>public void updateView(com.facebook.react.views.switchviewview.ReactSwitch view,
CatalystStylesDiffMap props)
ViewManagerupdateView in class SimpleViewManager<com.facebook.react.views.switchviewview.ReactSwitch>protected void addEventEmitters(ThemedReactContext reactContext, com.facebook.react.views.switchviewview.ReactSwitch view)
ViewManageraddEventEmitters in class ViewManager<com.facebook.react.views.switchviewview.ReactSwitch,ReactShadowNode>