public class ReactTextViewManager extends BaseViewManager<ReactTextView,ReactTextShadowNode>
TextView.
This is a "shadowing" view manager, which means that the NativeViewHierarchyManager will
not manage children of native TextView instances returned by this manager. Instead we use| Modifier and Type | Field and Description |
|---|---|
static java.lang.String |
REACT_CLASS |
PROP_TEST_ID| Constructor and Description |
|---|
ReactTextViewManager() |
| Modifier and Type | Method and Description |
|---|---|
ReactTextShadowNode |
createShadowNodeInstance()
This method should return a subclass of
ReactShadowNode which will be then used for
measuring position and size of the view. |
ReactTextView |
createViewInstance(ThemedReactContext context)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
java.lang.Class<ReactTextShadowNode> |
getShadowNodeClass()
This method should return
Class instance that represent type of shadow node that this
manager will return from ViewManager.createShadowNodeInstance(). |
void |
setLineHeight(ReactTextView view,
float lineHeight) |
void |
setNumberOfLines(ReactTextView view,
int numberOfLines) |
void |
setTextAlign(ReactTextView view,
java.lang.String textAlign) |
void |
updateExtraData(ReactTextView view,
java.lang.Object extraData)
Subclasses can implement this method to receive an optional extra data enqueued from the
corresponding instance of
ReactShadowNode in
ReactShadowNode.onCollectExtraUpdates(com.facebook.react.uimanager.UIViewOperationQueue). |
setAccessibilityComponentType, setAccessibilityLabel, setAccessibilityLiveRegion, setBackgroundColor, setDecomposedMatrix, setImportantForAccessibility, setOpacity, setRenderToHardwareTexture, setRotation, setScaleX, setScaleY, setTestId, setTranslateX, setTranslateYaddEventEmitters, createView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onAfterUpdateTransaction, onDropViewInstance, receiveCommand, updatePropertiespublic static final java.lang.String REACT_CLASS
public java.lang.String getName()
getName in class ViewManager<ReactTextView,ReactTextShadowNode>public ReactTextView createViewInstance(ThemedReactContext context)
ViewManagercreateViewInstance in class ViewManager<ReactTextView,ReactTextShadowNode>public void setNumberOfLines(ReactTextView view, int numberOfLines)
public void setTextAlign(ReactTextView view, @Nullable java.lang.String textAlign)
public void setLineHeight(ReactTextView view, float lineHeight)
public void updateExtraData(ReactTextView view, java.lang.Object extraData)
ViewManagerReactShadowNode in
ReactShadowNode.onCollectExtraUpdates(com.facebook.react.uimanager.UIViewOperationQueue).
Since css layout step and ui updates can be executed in separate thread apart of setting
x/y/width/height this is the recommended and thread-safe way of passing extra data from css
node to the native view counterpart.
TODO(7247021): Replace updateExtraData with generic update props mechanism after D2086999updateExtraData in class ViewManager<ReactTextView,ReactTextShadowNode>public ReactTextShadowNode createShadowNodeInstance()
ViewManagerReactShadowNode which will be then used for
measuring position and size of the view. In mose of the cases this should just return an
instance of ReactShadowNodecreateShadowNodeInstance in class ViewManager<ReactTextView,ReactTextShadowNode>public java.lang.Class<ReactTextShadowNode> getShadowNodeClass()
ViewManagerClass instance that represent type of shadow node that this
manager will return from ViewManager.createShadowNodeInstance().
This method will be used in the bridge initialization phase to collect properties exposed using
ReactProp (or ReactPropGroup) annotation from the ReactShadowNode
subclass specific for native view this manager provides.getShadowNodeClass in class ViewManager<ReactTextView,ReactTextShadowNode>Class object that represents type of shadow node used by this view manager.