| Class | Description |
|---|---|
| CustomStyleSpan | |
| DefaultStyleValuesUtil |
Utility class that access default values from style
|
| ReactFontManager |
Class responsible to load and cache Typeface objects.
|
| ReactRawTextManager |
Manages raw text nodes.
|
| ReactTagSpan |
Instances of this class are used to place reactTag information of nested text react nodes
into spannable text rendered by single
TextView |
| ReactTextInlineImageShadowNode |
ReactShadowNode class for Image embedded within a TextView. |
| ReactTextInlineImageViewManager |
Manages Images embedded in Text nodes.
|
| ReactTextShadowNode |
ReactShadowNode class for spannable text view. |
| ReactTextUpdate |
Class that contains the data needed for a text update.
|
| ReactTextView | |
| ReactTextViewManager |
Manages instances of spannable
TextView. |
| ReactVirtualTextViewManager |
Manages raw text nodes.
|
| ShadowStyleSpan | |
| TextInlineImageSpan |
TextInlineImageSpan is a span for Images that are inside
|