public class ReactTextInputShadowNode extends ReactTextShadowNode implements CSSNode.MeasureFunction
CSSNode.MeasureFunctionmFontSize, mNumberOfLines, PROP_TEXT, UNSET| Constructor and Description |
|---|
ReactTextInputShadowNode() |
| Modifier and Type | Method and Description |
|---|---|
void |
measure(CSSNode node,
float width,
MeasureOutput measureOutput)
Should measure the given node and put the result in the given MeasureOutput.
|
void |
onBeforeLayout()
This method will be called by
UIManagerModule once per batch, before calculating
layout. |
void |
onCollectExtraUpdates(UIViewOperationQueue uiViewOperationQueue)
Called after layout step at the end of the UI batch from
UIManagerModule. |
void |
setMostRecentEventCount(int mostRecentEventCount) |
void |
setPadding(int spacingType,
float padding) |
protected void |
setThemedContext(ThemedReactContext themedContext) |
fromTextCSSNode, isVirtual, isVirtualAnchor, markUpdated, setBackgroundColor, setColor, setFontFamily, setFontSize, setFontStyle, setFontWeight, setLineHeight, setNumberOfLines, setTextsetAlignItems, setAlignSelf, setBorderWidths, setBottom, setFlex, setFlexDirection, setFlexWrap, setHeight, setJustifyContent, setLeft, setMargins, setPaddings, setPosition, setRight, setShouldNotifyOnLayout, setTop, setWidthaddChildAt, addNativeChildAt, dirty, getChildAt, getNativeChildCount, getNativeOffsetForChild, getNativeParent, getParent, getReactTag, getRootNode, getScreenHeight, getScreenWidth, getScreenX, getScreenY, getThemedContext, getTotalNativeChildren, getViewClass, hasUpdates, indexOfNativeChild, isLayoutOnly, markUpdateSeen, onAfterUpdateTransaction, removeChildAt, removeNativeChildAt, setIsLayoutOnly, updatePropertiescalculateLayout, getAlignItems, getAlignSelf, getBorder, getChildCount, getFlex, getFlexDirection, getJustifyContent, getLayoutDirection, getLayoutHeight, getLayoutWidth, getLayoutX, getLayoutY, getMargin, getPadding, getPositionBottom, getPositionLeft, getPositionRight, getPositionTop, getPositionType, getStyleDirection, getStyleHeight, getStyleWidth, hasNewLayout, indexOf, isDirty, isMeasureDefined, markLayoutSeen, reset, setAlignItems, setAlignSelf, setBorder, setDefaultPadding, setDirection, setFlexDirection, setJustifyContent, setMargin, setMeasureFunction, setPositionBottom, setPositionLeft, setPositionRight, setPositionTop, setPositionType, setStyleHeight, setStyleWidth, setWrap, toString, valuesEqualprotected void setThemedContext(ThemedReactContext themedContext)
setThemedContext in class ReactShadowNodepublic void measure(CSSNode node, float width, MeasureOutput measureOutput)
CSSNode.MeasureFunctionmeasure in interface CSSNode.MeasureFunctionpublic void onBeforeLayout()
ReactShadowNodeUIManagerModule once per batch, before calculating
layout. Will be only called for nodes that are marked as updated with ReactShadowNode.markUpdated()
or require layouting (marked with ReactShadowNode.dirty()).onBeforeLayout in class ReactTextShadowNodepublic void setMostRecentEventCount(int mostRecentEventCount)
public void onCollectExtraUpdates(UIViewOperationQueue uiViewOperationQueue)
ReactShadowNodeUIManagerModule. May be used
to enqueue additional ui operations for the native view. Will only be called on nodes marked
as updated either with ReactShadowNode.dirty() or ReactShadowNode.markUpdated().onCollectExtraUpdates in class ReactTextShadowNodeuiViewOperationQueue - interface for enqueueing UI operationspublic void setPadding(int spacingType,
float padding)
setPadding in class CSSNode