public class ReactToolbarManager extends ViewGroupManager<Toolbar>
| Modifier and Type | Field and Description |
|---|---|
static java.lang.String |
PROP_ACTIONS |
static java.lang.String |
PROP_LOGO |
static java.lang.String |
PROP_NAV_ICON |
static java.lang.String |
PROP_SUBTITLE |
static java.lang.String |
PROP_SUBTITLE_COLOR |
static java.lang.String |
PROP_TITLE |
static java.lang.String |
PROP_TITLE_COLOR |
| Constructor and Description |
|---|
ReactToolbarManager() |
| Modifier and Type | Method and Description |
|---|---|
protected void |
addEventEmitters(ThemedReactContext reactContext,
Toolbar view)
Subclasses can override this method to install custom event emitters on the given View.
|
protected Toolbar |
createViewInstance(ThemedReactContext reactContext)
Subclasses should return a new View instance of the proper type.
|
java.lang.String |
getName() |
boolean |
needsCustomLayoutForChildren()
Returns whether this View type needs to handle laying out its own children instead of
deferring to the standard css-layout algorithm.
|
void |
updateView(Toolbar toolbar,
CatalystStylesDiffMap props)
Subclass should use this method to populate native view with updated style properties.
|
addView, createCSSNodeInstance, getChildAt, getChildCount, removeView, updateExtraDatacreateView, getCommandsMap, getExportedCustomBubblingEventTypeConstants, getExportedCustomDirectEventTypeConstants, getExportedViewConstants, getNativeProps, onAfterUpdateTransaction, onDropViewInstance, receiveCommand, updatePropertiespublic static final java.lang.String PROP_LOGO
public static final java.lang.String PROP_NAV_ICON
public static final java.lang.String PROP_SUBTITLE
public static final java.lang.String PROP_SUBTITLE_COLOR
public static final java.lang.String PROP_TITLE
public static final java.lang.String PROP_TITLE_COLOR
public static final java.lang.String PROP_ACTIONS
public java.lang.String getName()
getName in class ViewManager<Toolbar,ReactShadowNode>protected Toolbar createViewInstance(ThemedReactContext reactContext)
ViewManagercreateViewInstance in class ViewManager<Toolbar,ReactShadowNode>public void updateView(Toolbar toolbar,
CatalystStylesDiffMap props)
ViewManagerupdateView in class ViewGroupManager<Toolbar>protected void addEventEmitters(ThemedReactContext reactContext, Toolbar view)
ViewManageraddEventEmitters in class ViewManager<Toolbar,ReactShadowNode>public boolean needsCustomLayoutForChildren()
ViewGroupManagerneedsCustomLayoutForChildren in class ViewGroupManager<Toolbar>