public class SoLoader
extends java.lang.Object
com.facebook.base.app.DelegatingApplication will automatically register itself
with SoLoader before running application-specific code; most applications do not need to call
init(android.content.Context, boolean) explicitly.| Constructor and Description |
|---|
SoLoader() |
| Modifier and Type | Method and Description |
|---|---|
static void |
init(android.content.Context context,
boolean isNativeExopackageEnabled)
Initializes native code loading for this app; this class's other static facilities cannot be
used until this
init(android.content.Context, boolean) is called. |
static void |
loadLibrary(java.lang.String shortName)
Load a shared library, initializing any JNI binding it contains.
|
static void |
setInTestMode()
Turn shared-library loading into a no-op.
|
static java.io.File |
unpackLibraryAndDependencies(java.lang.String shortName)
Unpack library and its dependencies, returning the location of the unpacked library file.
|
public static void init(@Nullable
android.content.Context context,
boolean isNativeExopackageEnabled)
init(android.content.Context, boolean) is called. This method is idempotent: calls after the first are
ignored.context - - application context.isNativeExopackageEnabled - - whether native exopackage feature is enabled in the build.public static void setInTestMode()
public static void loadLibrary(java.lang.String shortName)
throws java.lang.UnsatisfiedLinkError
shortName - Name of library to find, without "lib" prefix or ".so" suffixjava.lang.UnsatisfiedLinkErrorpublic static java.io.File unpackLibraryAndDependencies(java.lang.String shortName)
throws java.lang.UnsatisfiedLinkError
shortName - Name of library to find, without "lib" prefix or ".so" suffixjava.lang.UnsatisfiedLinkError