public abstract class SoSource
extends java.lang.Object
| Modifier and Type | Field and Description |
|---|---|
static int |
LOAD_FLAG_ALLOW_IMPLICIT_PROVISION
Allow loadLibrary to implicitly provide the library instead of actually loading it.
|
static int |
LOAD_RESULT_IMPLICITLY_PROVIDED
This SoSource did not load the library, but verified that the system loader will load it if
some other library depends on it.
|
static int |
LOAD_RESULT_LOADED
This SoSource loaded the given library.
|
static int |
LOAD_RESULT_NOT_FOUND
This SoSource doesn't know how to provide the given library.
|
| Constructor and Description |
|---|
SoSource() |
| Modifier and Type | Method and Description |
|---|---|
abstract int |
loadLibrary(java.lang.String soName,
int LoadFlags)
Load a shared library library into this process.
|
abstract java.io.File |
unpackLibrary(java.lang.String soName)
Ensure that a shared library exists on disk somewhere.
|
public static final int LOAD_RESULT_NOT_FOUND
public static final int LOAD_RESULT_LOADED
public static final int LOAD_RESULT_IMPLICITLY_PROVIDED
public static final int LOAD_FLAG_ALLOW_IMPLICIT_PROVISION
public abstract int loadLibrary(java.lang.String soName,
int LoadFlags)
throws java.io.IOException
loadLibrary(java.lang.String, int).soName - Name of library to loadloadFlags - Zero or more of the LOAD_FLAG_XXX constants.java.io.IOExceptionpublic abstract java.io.File unpackLibrary(java.lang.String soName)
throws java.io.IOException
loadLibrary(java.lang.String, int).soName - Name of library to loadnull if not.java.io.IOException