| Class | Description |
|---|---|
| ApkSoSource |
SoSource that extracts libraries from an APK to the filesystem. |
| DirectorySoSource |
SoSource that finds shared libraries in a given directory. |
| Elf32_Dyn | |
| Elf32_Ehdr | |
| Elf32_Phdr | |
| Elf32_Shdr | |
| Elf64_Dyn | |
| Elf64_Ehdr | |
| Elf64_Phdr | |
| Elf64_Shdr | |
| ExoSoSource |
SoSource that retrieves libraries from an exopackage repository. |
| FileLocker | |
| MinElf |
Extract SoLoader boottsrap information from an ELF file.
|
| NativeLibrary |
This is the base class for all the classes representing certain native library.
|
| NoopSoSource |
SoSource that does nothing and pretends to successfully load all libraries. |
| SoLoader |
Note that
com.facebook.base.app.DelegatingApplication will automatically register itself
with SoLoader before running application-specific code; most applications do not need to call
SoLoader.init(android.content.Context, boolean) explicitly. |
| SoSource |