public class ProxyJavaScriptExecutor extends JavaScriptExecutor
CatalystInstance.Builder, catalyst native code will delegate
low level javascript calls to the implementation of ProxyJavaScriptExecutor.JavaJSExecutor interface provided
with the constructor of this class.| Modifier and Type | Class and Description |
|---|---|
static interface |
ProxyJavaScriptExecutor.JavaJSExecutor
This is class represents java version of native js executor interface.
|
static class |
ProxyJavaScriptExecutor.ProxyExecutorException |
| Constructor and Description |
|---|
ProxyJavaScriptExecutor(ProxyJavaScriptExecutor.JavaJSExecutor executor)
Create
ProxyJavaScriptExecutor instance |
| Modifier and Type | Method and Description |
|---|---|
void |
close()
Close this executor and cleanup any resources that it was using.
|
public ProxyJavaScriptExecutor(ProxyJavaScriptExecutor.JavaJSExecutor executor)
ProxyJavaScriptExecutor instanceexecutor - implementation of ProxyJavaScriptExecutor.JavaJSExecutor which will be responsible for handling
javascript callspublic void close()
JavaScriptExecutorclose in class JavaScriptExecutor