| Interface | Description |
|---|---|
| QueueThreadExceptionHandler |
Interface for a class that knows how to handle an Exception thrown while executing a Runnable
submitted via
MessageQueueThread.runOnQueue(java.lang.Runnable). |
| Class | Description |
|---|---|
| CatalystQueueConfiguration |
Specifies which
MessageQueueThreads must be used to run the various contexts of
execution within catalyst (Main UI thread, native modules, and JS). |
| CatalystQueueConfigurationSpec |
Spec for creating a CatalystQueueConfiguration.
|
| CatalystQueueConfigurationSpec.Builder | |
| MessageQueueThread |
Encapsulates a Thread that has a
Looper running on it that can accept Runnables. |
| MessageQueueThreadHandler |
Handler that can catch and dispatch Exceptions to an Exception handler.
|
| MessageQueueThreadSpec |
Spec for creating a MessageQueueThread.
|
| NativeRunnable |
A Runnable that has a native run implementation.
|
| Enum | Description |
|---|---|
| MessageQueueThreadSpec.ThreadType |