| Class | Description |
|---|---|
| ReactEditText |
A wrapper around the EditText that lets us better control what happens when an EditText gets
focused or blurred, and when to display the soft keyboard and when not to.
|
| ReactTextInputManager |
Manages instances of TextInput.
|
| ReactTextUpdate |
Class that contains the data needed for a Text Input text update.
|